@@ -66,10 +66,6 @@ setMethod("relistToClass", "XString",
     function(x) paste0(class(x), "Set")
 )
 
-setMethod("splitAsListReturnedClass", "XString",
-    function(x) {.Deprecated("relistToClass"); paste0(class(x), "Set")}
-)
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Accessor-like methods.
@@ -484,6 +480,16 @@ setMethod("as.character", "XStringSet",
     }
 )
 
+### TODO: Turn this into an S3/S4 combo for as.data.frame.XStringSet
+setMethod("as.data.frame", "XStringSet",
+    function(x, row.names=NULL, optional=FALSE)
+    {
+        x <- as.character(x)
+        as.data.frame(x, row.names=NULL, optional=optional,
+                         stringsAsFactors=FALSE)
+    }
+)
+
 setMethod("as.vector", "XStringSet",
     function(x, mode="any")
     {
