@@ -60,20 +60,11 @@ setMethod("relistToClass", "XStringSet",
     function(x) paste0(seqtype(x), "StringSetList")
 )
 
-setMethod("splitAsListReturnedClass", "XStringSet",
-    function(x) {
-        .Deprecated("relistToClass")
-        paste0(seqtype(x), "StringSetList")
-    }
-)
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Accessor-like methods.
 ###
 
-partitioning <- function(x) .Defunct("PartitioningByEnd")
-
 setMethod("nchar", "XStringSetList", IRanges:::nchar_CompressedList)
 
 
@@ -165,15 +156,18 @@ setReplaceMethod("seqtype", "XStringSetList",
 ### User interface to the XStringSetList() constructor
 ###
 
+BStringSetList <- function(..., use.names=TRUE)
+    XStringSetList("B", ..., use.names=use.names)
+
 DNAStringSetList <- function(..., use.names=TRUE)
-{
     XStringSetList("DNA", ..., use.names=use.names)
-}
+
+RNAStringSetList <- function(..., use.names=TRUE)
+    XStringSetList("RNA", ..., use.names=use.names)
 
 AAStringSetList <- function(..., use.names=TRUE)
-{
     XStringSetList("AA", ..., use.names=use.names)
-}
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### The "show" method.
@@ -188,7 +182,7 @@ setMethod("show", "XStringSetList",
 )
 
 ### Display in a DataTable.
-showAsCell <- IRanges:::showAsCell
+showAsCell <- S4Vectors:::showAsCell
 setMethod("showAsCell", "XStringSetList",
      function(object) showAsCell(CharacterList(object))
 )
