@@ -24,7 +24,7 @@ pairwiseAlignment(pattern = c("succeed", "precede"), subject = "supersede",
 ### code chunk number 4: main3
 ###################################################
 pairwiseAlignment(pattern = c("succeed", "precede"), subject = "supersede",
-                  gapOpening = 0, gapExtension = -1)
+                  gapOpening = 0, gapExtension = 1)
 
 
 ###################################################
@@ -35,7 +35,7 @@ submat <-
 diag(submat) <- 0
 pairwiseAlignment(pattern = c("succeed", "precede"), subject = "supersede",
                   substitutionMatrix = submat,
-                  gapOpening = 0, gapExtension = -1)
+                  gapOpening = 0, gapExtension = 1)
 
 
 ###################################################
@@ -46,7 +46,7 @@ submat <-
 diag(submat) <- 0
 pairwiseAlignment(pattern = c("succeed", "precede"), subject = "supersede",
                   substitutionMatrix = submat,
-                  gapOpening = 0, gapExtension = -1, scoreOnly = TRUE)
+                  gapOpening = 0, gapExtension = 1, scoreOnly = TRUE)
 
 
 ###################################################
@@ -73,7 +73,7 @@ diag(submat) <- 0
 psa2 <-
   pairwiseAlignment(pattern = c("succeed", "precede"), subject = "supersede",
                     substitutionMatrix = submat,
-                    gapOpening = 0, gapExtension = -1)
+                    gapOpening = 0, gapExtension = 1)
 class(pattern(psa2))
 
 
@@ -86,7 +86,7 @@ diag(submat) <- 0
 psa2 <-
   pairwiseAlignment(pattern = c("succeed", "precede"), subject = "supersede",
                     substitutionMatrix = submat,
-                    gapOpening = 0, gapExtension = -1)
+                    gapOpening = 0, gapExtension = 1)
 score(psa2)
 nedit(psa2)
 nmatch(psa2)
@@ -138,7 +138,7 @@ function(pattern, x, ignore.case = FALSE, value = FALSE, max.distance = 0.1)
     - pairwiseAlignment(pattern = x, subject = pattern,
                         substitutionMatrix = substitutionMatrix,
                         type = "local-global",
-                        gapOpening = 0, gapExtension = -1,
+                        gapOpening = 0, gapExtension = 1,
                         scoreOnly = TRUE)
   whichClose <- which(distance <= max.distance)
   if (value)
@@ -158,7 +158,7 @@ data(BLOSUM50)
 BLOSUM50[1:4,1:4]
 nwdemo <- 
   pairwiseAlignment(AAString("PAWHEAE"), AAString("HEAGAWGHEE"), substitutionMatrix = BLOSUM50,
-                    gapOpening = 0, gapExtension = -8)
+                    gapOpening = 0, gapExtension = 8)
 nwdemo
 compareStrings(nwdemo)
 pid(nwdemo)
@@ -224,11 +224,11 @@ randomStrings <- DNAStringSet(randomStrings)
 submat1 <- nucleotideSubstitutionMatrix(match = 0, mismatch = -1, baseOnly = TRUE)
 randomScores1 <-
   pairwiseAlignment(randomStrings, adapter, substitutionMatrix = submat1,
-                    gapOpening = 0, gapExtension = -1, scoreOnly = TRUE)
+                    gapOpening = 0, gapExtension = 1, scoreOnly = TRUE)
 quantile(randomScores1, seq(0.99, 1, by = 0.001))
 adapterAligns1 <-
   pairwiseAlignment(adapterStrings, adapter, substitutionMatrix = submat1,
-                    gapOpening = 0, gapExtension = -1)
+                    gapOpening = 0, gapExtension = 1)
 table(score(adapterAligns1) > quantile(randomScores1, 0.999), experiment[["width"]])
 
 
@@ -239,12 +239,12 @@ table(score(adapterAligns1) > quantile(randomScores1, 0.999), experiment[["width
 submat2 <- nucleotideSubstitutionMatrix(match = 1, mismatch = -Inf, baseOnly = TRUE)
 randomScores2 <-
   pairwiseAlignment(randomStrings, adapter, substitutionMatrix = submat2,
-                    type = "local", gapOpening = 0, gapExtension = -Inf,
+                    type = "local", gapOpening = 0, gapExtension = Inf,
                     scoreOnly = TRUE)
 quantile(randomScores2, seq(0.99, 1, by = 0.001))
 adapterAligns2 <-
   pairwiseAlignment(adapterStrings, adapter, substitutionMatrix = submat2,
-                    type = "local", gapOpening = 0, gapExtension = -Inf)
+                    type = "local", gapOpening = 0, gapExtension = Inf)
 table(score(adapterAligns2) > quantile(randomScores2, 0.999), experiment[["width"]])
 # Determine if the correct end was chosen
 table(start(pattern(adapterAligns2)) > 37 - end(pattern(adapterAligns2)),
@@ -258,12 +258,12 @@ table(start(pattern(adapterAligns2)) > 37 - end(pattern(adapterAligns2)),
 submat3 <- nucleotideSubstitutionMatrix(match = 1, mismatch = -Inf, baseOnly = TRUE)
 randomScores3 <-
   pairwiseAlignment(randomStrings, adapter, substitutionMatrix = submat3,
-                    type = "overlap", gapOpening = 0, gapExtension = -Inf,
+                    type = "overlap", gapOpening = 0, gapExtension = Inf,
                     scoreOnly = TRUE)
 quantile(randomScores3, seq(0.99, 1, by = 0.001))
 adapterAligns3 <-
   pairwiseAlignment(adapterStrings, adapter, substitutionMatrix = submat3,
-                    type = "overlap", gapOpening = 0, gapExtension = -Inf)
+                    type = "overlap", gapOpening = 0, gapExtension = Inf)
 table(score(adapterAligns3) > quantile(randomScores3, 0.999), experiment[["width"]])
 # Determine if the correct end was chosen
 table(end(pattern(adapterAligns3)) == 36, experiment[["side"]])
@@ -414,7 +414,7 @@ pairwiseAlignment("zyzzyx", "syzygy", type = "overlap")
 ###################################################
 ### code chunk number 30: ans1b
 ###################################################
-pairwiseAlignment("zyzzyx", "syzygy", type = "overlap", gapExtension = -Inf)
+pairwiseAlignment("zyzzyx", "syzygy", type = "overlap", gapExtension = Inf)
 
 
 ###################################################
@@ -467,7 +467,7 @@ aligned(subject(ex3))
 submat <- matrix(-1, nrow = 26, ncol = 26, dimnames = list(letters, letters))
 diag(submat) <- 0
 - pairwiseAlignment("zyzzyx", "syzygy", substitutionMatrix = submat,
-                    gapOpening = 0, gapExtension = -1, scoreOnly = TRUE)
+                    gapOpening = 0, gapExtension = 1, scoreOnly = TRUE)
 
 
 ###################################################
@@ -481,7 +481,7 @@ stringDist(c("zyzzyx", "syzygy", "succeed", "precede", "supersede"))
 ###################################################
 data(BLOSUM62)
 pairwiseAlignment(AAString("PAWHEAE"), AAString("HEAGAWGHEE"), substitutionMatrix = BLOSUM62,
-                  gapOpening = -12, gapExtension = -4)
+                  gapOpening = 12, gapExtension = 4)
 
 
 ###################################################
@@ -503,7 +503,7 @@ submat1 <- nucleotideSubstitutionMatrix(match = 0, mismatch = -1, baseOnly = TRU
 quantile(randomScores1, seq(0.99, 1, by = 0.001))
 ex6Aligns1 <-
   pairwiseAlignment(ex6Strings, adapter, substitutionMatrix = submat1,
-                    gapOpening = 0, gapExtension = -1)
+                    gapOpening = 0, gapExtension = 1)
 table(score(ex6Aligns1) > quantile(randomScores1, 0.999), experiment[["width"]])
 
 ## Method 2:  Use consecutive matches anywhere in string with an FDR of 1e-03
@@ -511,7 +511,7 @@ submat2 <- nucleotideSubstitutionMatrix(match = 1, mismatch = -Inf, baseOnly = T
 quantile(randomScores2, seq(0.99, 1, by = 0.001))
 ex6Aligns2 <-
   pairwiseAlignment(ex6Strings, adapter, substitutionMatrix = submat2,
-                    type = "local", gapOpening = 0, gapExtension = -Inf)
+                    type = "local", gapOpening = 0, gapExtension = Inf)
 table(score(ex6Aligns2) > quantile(randomScores2, 0.999), experiment[["width"]])
 # Determine if the correct end was chosen
 table(start(pattern(ex6Aligns2)) > 37 - end(pattern(ex6Aligns2)),
@@ -521,7 +521,7 @@ table(start(pattern(ex6Aligns2)) > 37 - end(pattern(ex6Aligns2)),
 submat3 <- nucleotideSubstitutionMatrix(match = 1, mismatch = -Inf, baseOnly = TRUE)
 ex6Aligns3 <-
   pairwiseAlignment(ex6Strings, adapter, substitutionMatrix = submat3,
-                    type = "overlap", gapOpening = 0, gapExtension = -Inf)
+                    type = "overlap", gapOpening = 0, gapExtension = Inf)
 table(score(ex6Aligns3) > quantile(randomScores3, 0.999), experiment[["width"]])
 # Determine if the correct end was chosen
 table(end(pattern(ex6Aligns3)) == 36, experiment[["side"]])
@@ -654,6 +654,6 @@ round((newTimings - newScoreOnlyTimings) / newTimings, 2)
 ###################################################
 ### code chunk number 48: sessinfo
 ###################################################
-toLatex(sessionInfo())
+sessionInfo()
 
 
