@@ -29,11 +29,6 @@ static const R_CallMethodDef callMethods[] = {
 /* utils.c */
 	CALLMETHOD_DEF(debug_utils, 0),
 
-/* io_utils.c */
-	CALLMETHOD_DEF(new_input_ExternalFilePtr, 1),
-	CALLMETHOD_DEF(new_output_ExternalFilePtr, 4),
-	CALLMETHOD_DEF(finalize_ExternalFilePtr, 1),
-
 /* RoSeqs_utils.c */
 	CALLMETHOD_DEF(debug_RoSeqs_utils, 0),
 
