@@ -3,8 +3,9 @@
  *                           Author: Herve Pages                            *
  ****************************************************************************/
 #include "Biostrings.h"
-#include "IRanges_interface.h"
 #include "XVector_interface.h"
+#include "IRanges_interface.h"
+#include "S4Vectors_interface.h"
 
 static int debug = 0;
 
@@ -202,7 +203,7 @@ SEXP XStringSet_unlist(SEXP x)
 		Ocopy_bytes_to_i1i2_with_lkup(tag_offset,
 				tag_offset + xx.length - 1,
 				(char *) RAW(ans_tag), LENGTH(ans_tag),
-				xx.seq, xx.length,
+				xx.ptr, xx.length,
 				NULL, 0);
 		tag_offset += xx.length;
 	}
