@@ -3,8 +3,8 @@
  *                           Author: Herve Pages                            *
  ****************************************************************************/
 #include "Biostrings.h"
-#include "IRanges_interface.h"
 #include "XVector_interface.h"
+#include "IRanges_interface.h"
 
 #include <stdlib.h>  /* for realloc() */
 
@@ -62,7 +62,8 @@ char _DNAencode(char c)
 
 	code = DNA_enc_byte2code.byte2code[(unsigned char) c];
 	if (code == NA_INTEGER)
-		error("_DNAencode(): key %d not in lookup table", (int) c);
+		error("_DNAencode(): invalid DNAString "
+		      "input character: '%c' (byte value %d)", c, (int) c);
 	return code;
 }
 
@@ -72,7 +73,8 @@ char _DNAdecode(char code)
 
 	c = DNA_dec_byte2code.byte2code[(unsigned char) code];
 	if (c == NA_INTEGER)
-		error("_DNAdecode(): key %d not in lookup table", (int) code);
+		error("_DNAdecode(): invalid DNAString "
+		      "internal code: %d", (int) code);
 	return c;
 }
 
@@ -90,7 +92,8 @@ char _RNAencode(char c)
 
 	code = RNA_enc_byte2code.byte2code[(unsigned char) c];
 	if (code == NA_INTEGER)
-		error("_RNAencode(): key %d not in lookup table", (int) c);
+		error("_RNAencode(): invalid RNAString "
+		      "input character: '%c' (byte value %d)", c, (int) c);
 	return code;
 }
 
@@ -100,7 +103,8 @@ char _RNAdecode(char code)
 
 	c = RNA_dec_byte2code.byte2code[(unsigned char) code];
 	if (c == NA_INTEGER)
-		error("_RNAdecode(): key %d not in lookup table", (int) code);
+		error("_RNAdecode(): invalid RNAString "
+		      "internal code: %d", (int) code);
 	return (char) c;
 }
 
@@ -116,10 +120,10 @@ void _copy_CHARSXP_to_Chars_holder(Chars_holder *dest, SEXP src,
 
 	i1 = start_in_src - 1;
 	i2 = i1 + dest->length - 1;
-	/* dest.seq is a const char * so we need to cast it
+	/* dest.ptr is a const char * so we need to cast it
 	   to char * before we can write to it */
 	Ocopy_bytes_from_i1i2_with_lkup(i1, i2,
-			(char *) dest->seq, dest->length,
+			(char *) dest->ptr, dest->length,
 			CHAR(src), LENGTH(src),
 			lkup, lkup_length);
 	return;
@@ -137,7 +141,7 @@ SEXP _new_CHARSXP_from_Chars_holder(const Chars_holder *x, SEXP lkup)
 	char *new_buf;
 
 	if (lkup == R_NilValue)
-		return mkCharLen(x->seq, x->length);
+		return mkCharLen(x->ptr, x->length);
 	new_buflength = x->length;
 	if (new_buflength > buflength) {
 		new_buf = (char *) realloc(buf, new_buflength);
@@ -149,7 +153,7 @@ SEXP _new_CHARSXP_from_Chars_holder(const Chars_holder *x, SEXP lkup)
 	}
 	Ocopy_bytes_to_i1i2_with_lkup(0, x->length - 1,
 		buf, buflength,
-		x->seq, x->length,
+		x->ptr, x->length,
 		INTEGER(lkup), LENGTH(lkup));
 	return mkCharLen(buf, x->length);
 }
